@@ -123,7 +123,7 @@ void log_error( int id, const char *host, const char *message, ... )
             fprintf( stdout, "\n" );
         }
 #else
-    syslog( ( syslog_facility | LOG_ERR ), header );
+    syslog( ( syslog_facility | LOG_ERR ), "%s", header );
 #endif
 
     /* if we have a log application running, pipe to it. */
@@ -203,7 +203,7 @@ void log_info( int id, const char *host, const char *message, ... )
             fprintf( stdout, "\n" );
         }
 #else
-    syslog( ( syslog_facility | LOG_INFO ), header );
+    syslog( ( syslog_facility | LOG_INFO ), "%s", header );
 #endif
 
     /* if we have a log application running, pipe to it. */
@@ -283,7 +283,7 @@ void log_warning( int id, const char *host, const char *message, ... )
             fprintf( stdout, "\n" );
         }
 #else
-    syslog( ( syslog_facility | LOG_WARNING ), header );
+    syslog( ( syslog_facility | LOG_WARNING ), "%s", header );
 #endif
 
     /* if we have a log application running, pipe to it. */
@@ -350,7 +350,7 @@ int log_cmp_message( int id, OSI_DB_CTX *context, const char *message, ... )
                     NULL);                /* no raw data */
         }
 #else
-        syslog( ( syslog_facility | LOG_INFO ), buffer );
+        syslog( ( syslog_facility | LOG_INFO ), "%s", buffer );
 #endif
     }
 
