@@ -1,7 +1,7 @@
 
 /******************************************************************************
 **
-**  Copyright (C) 2005 Brian Wotring.
+**  Copyright (C) 2006 Brian Wotring.
 **
 **  This program is free software; you can redistribute it and/or
 **  modify it, however, you cannot sell it.
@@ -47,7 +47,7 @@
 
 extern char root_path[MAX_PATH_LENGTH];
 extern OSI_MANAGEMENT_CONFIG *config;
-
+extern int quiet_mode;
 
 OSI_DB_CTX * osi_db_ctx_new()
 {
@@ -66,7 +66,16 @@ OSI_DB_CTX * osi_db_ctx_new()
 
         context->compare_mask = CMP_MASK_DEFAULT;
 
-        context->use_system_log     = TRUE;
+        if ( quiet_mode )
+        {
+            context->use_system_log = FALSE;
+        }
+
+        else
+        {
+            context->use_system_log     = TRUE;
+        }
+
         context->include_missing    = TRUE;
         context->include_new        = TRUE;
         context->include_system     = TRUE;
@@ -164,6 +173,7 @@ void osi_db_ctx_set_log_file( OSI_DB_CTX *context, const char *filepath )
 
 osi_bool md_compare_record_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
 {
+    int rc;
     int result;
     int record_size;
 
@@ -208,12 +218,15 @@ osi_bool md_compare_record_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
         if ( ( result == OSI_ERROR_DB_ITEM_NOT_FOUND ) &&
              ( context->include_missing ) )
         {
-            log_cmp_message( LOG_ID_CMP_FILE_MISSING, context,
-                             "[%s][missing][%s]",
-                             context->host, name );
+            rc = log_cmp_message( LOG_ID_CMP_FILE_MISSING, context,
+                                 "[%s][missing][%s]",
+                                 context->host, name );
 
-            context->diff_count++;
-            context->missing_count++;
+            if ( rc > 0 )
+            {
+                context->diff_count++;
+                context->missing_count++;
+            }
         }
 
         result = osi_scan_db_get_next_record( db1, r1, record_size );
@@ -233,11 +246,14 @@ osi_bool md_compare_record_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
 
             if( result == OSI_ERROR_DB_ITEM_NOT_FOUND )
             {
-                log_cmp_message( LOG_ID_CMP_FILE_NEW, context,
-                                 "[%s][new][%s]", context->host, name );
+                rc = log_cmp_message( LOG_ID_CMP_FILE_NEW, context,
+                                     "[%s][new][%s]", context->host, name );
 
-                context->diff_count++;
-                context->new_count++;
+                if ( rc > 0 )
+                {
+                    context->diff_count++;
+                    context->new_count++;
+                }
             }
 
             result = osi_scan_db_get_next_record( db2, r2, record_size );
@@ -252,6 +268,7 @@ osi_bool md_compare_record_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
 
 osi_bool md_compare_system_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
 {
+    int rc;
     int result;
     int record_size;
 
@@ -281,8 +298,6 @@ osi_bool md_compare_system_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
                                                        record_size, name );
         if( result == OSI_DB_OK )
         {
-            int rc = 0;
-
             /* compare system data entries. */
 
             char *r1_data = get_scan_record_system_data( r1 );
@@ -309,7 +324,6 @@ osi_bool md_compare_system_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
 
         else if( result == OSI_ERROR_DB_ITEM_NOT_FOUND )
         {
-            int rc = 0;
             SCAN_RECORD_TEXT_1 *rec = (SCAN_RECORD_TEXT_1 *)r1;
 
             rc = log_cmp_message( LOG_ID_CMP_GENERIC_MISSING, context,
@@ -340,7 +354,6 @@ osi_bool md_compare_system_db( OSI_DB_CTX *context, OSI_DB *db1, OSI_DB *db2 )
 
         if( result == OSI_ERROR_DB_ITEM_NOT_FOUND )
         {
-            int rc = 0;
             SCAN_RECORD_TEXT_1 *rec = (SCAN_RECORD_TEXT_1 *)r2;
 
             rc = log_cmp_message( LOG_ID_CMP_GENERIC_NEW, context,
@@ -465,7 +478,8 @@ osi_bool md_compare_db_records( OSI_DB_CTX *context,
 
         if( ( mask & ATTR_CHECKSUM ) && 
             ( r1->checksum_algorithm == r2->checksum_algorithm ) &&
-              strcmp( r1->checksum, r2->checksum ) != 0 )
+              strcmp( (const char *)r1->checksum,
+                      (const char *)r2->checksum ) != 0 )
         {
             context->changed_mask |= ATTR_CHECKSUM;
         }
@@ -556,7 +570,8 @@ osi_bool md_compare_db_records( OSI_DB_CTX *context,
 
         if( ( mask & ATTR_CHECKSUM ) &&
             ( r1->checksum_algorithm == r2->checksum_algorithm ) &&
-              strcmp( r1->checksum, r2->checksum ) != 0 )
+              strcmp( (const char *)r1->checksum,
+                      (const char *)r2->checksum ) != 0 )
         {
             context->changed_mask |= ATTR_CHECKSUM;
         }
